@@ -15,6 +15,7 @@ import unittest
 from collections import defaultdict, namedtuple
 from random import shuffle
 import pytest
+from executing._utils import mangled_name
 
 sys.path.append(os.path.dirname(os.path.dirname(__file__)))
 
@@ -715,11 +716,7 @@ def sample_files(samples):
 @pytest.mark.skipif(sys.version_info<(3,),reason="no 2.7 support")
 def test_small_samples(full_filename, result_filename):
     skip_sentinel = [
-        "load_deref",
         "4851dc1b626a95e97dbe0c53f96099d165b755dd1bd552c6ca771f7bca6d30f5",
-        "508ccd0dcac13ecee6f0cea939b73ba5319c780ddbb6c496be96fe5614871d4a",
-        "fc6eb521024986baa84af2634f638e40af090be4aa70ab3c22f3d022e8068228",
-        "42a37b8a823eb2e510b967332661afd679c82c60b7177b992a47c16d81117c8a",
         "206e0609ff0589a0a32422ee902f09156af91746e27157c32c9595d12072f92a",
     ]
 
@@ -1077,6 +1074,7 @@ class TestFiles:
                     p()
 
                     p("ast node:")
+                    p(mangled_name(node))
                     p(ast_dump(node, indent=4))
 
                     parents = []
@@ -1369,6 +1367,16 @@ class TestFiles:
                 if (sys.version_info>=(3,13) and inst.opname=="STORE_NAME" and inst.argval in ("__firstlineno__","__static_attributes__")):
                     continue
 
+                if (sys.version_info>=(3,14) and inst.opname=="STORE_NAME" and inst.argval in ("__annotate_func__","__classdictcell__","__classcell__")):
+                    continue
+
+                if (
+                    sys.version_info >= (3, 14)
+                    and inst.positions.col_offset == inst.positions.end_col_offset == 0
+                ):
+                    continue
+
+
                 # report more information for debugging
                 print("mapping failed")
 
@@ -1429,11 +1437,12 @@ class TestFiles:
 
                 raise
 
-            # `argval` isn't set for all relevant instructions in python 2
-            # The relation between `ast.Name` and `argval` is already
-            # covered by the verifier and much more complex in python 3.11 
-            if isinstance(node, ast.Name) and not py11:
-                assert inst.argval == node.id, (inst, ast.dump(node))
+            if isinstance(node, ast.Name) and inst.opname != "CALL_INTRINSIC_1" and inst.argval not in ("__classdict__","__classdictcell__","__static_attributes__"):
+                # CALL_INTRINSIC_1 and some special names are excuded here because they are generated by cpython for some synthetic code
+                if isinstance(inst.argval,tuple):
+                    assert  mangled_name(node) in inst.argval 
+                else:
+                    assert  mangled_name(node) == inst.argval 
 
             if ex.decorator:
                 decorators[(node.lineno, node.name)].append(ex.decorator)
