@@ -3,6 +3,7 @@ import inspect
 import linecache
 import os
 import sys
+import dis
 from time import sleep
 
 import asttokens
@@ -13,7 +14,10 @@ from littleutils import SimpleNamespace
 import executing.executing
 from executing import Source, NotOneValueFound
 from executing._exceptions import KnownIssue
-from executing.executing import is_ipython_cell_code, attr_names_match, is_rewritten_by_pytest
+from executing.executing import is_ipython_cell_code, is_rewritten_by_pytest
+from executing._utils import get_instructions, mangled_name
+
+from textwrap import indent
 
 sys.path.append(os.path.dirname(os.path.dirname(__file__)))
 
@@ -56,20 +60,6 @@ def test_ipython_cell_code():
     )
 
 
-def test_attr_names_match():
-    assert attr_names_match("foo", "foo")
-
-    assert not attr_names_match("foo", "_foo")
-    assert not attr_names_match("foo", "__foo")
-    assert not attr_names_match("_foo", "foo")
-    assert not attr_names_match("__foo", "foo")
-
-    assert attr_names_match("__foo", "_Class__foo")
-    assert not attr_names_match("_Class__foo", "__foo")
-    assert not attr_names_match("__foo", "Class__foo")
-    assert not attr_names_match("__foo", "_Class_foo")
-
-
 def test_source_file_text_change(tmpdir):
     # Check that Source.for_filename notices changes in file contents
     # (assuming that linecache can notice)
@@ -167,12 +157,8 @@ ex = Source.executing(frame)
     assert ex.source.text == fake_text
 
 
-if sys.version_info >= (3, 11):
-    from executing._position_node_finder import mangled_name
-    from textwrap import indent
-    import dis
 
-    def test_mangled_name():
+def test_mangled_name():
         def result(*code_levels):
             code = ""
             for i, level in enumerate(code_levels):
@@ -184,31 +170,36 @@ if sys.version_info >= (3, 11):
                 for child in ast.iter_child_nodes(parent):
                     child.parent = parent
 
+
+            ast_types=(
+                ast.Name,
+                ast.Attribute,
+                ast.alias,
+                ast.FunctionDef,
+                ast.ClassDef,
+                ast.ExceptHandler,
+                ast.AsyncFunctionDef,
+            )
+
             tree_names = {
                 mangled_name(n)
                 for n in ast.walk(tree)
                 if isinstance(
                     n,
-                    (
-                        ast.Name,
-                        ast.Attribute,
-                        ast.alias,
-                        ast.FunctionDef,
-                        ast.ClassDef,
-                        ast.AsyncFunctionDef,
-                        ast.ExceptHandler,
-                    ),
+                ast_types
+                    ,
                 )
             }
 
             def collect_names(code):
-                for instruction in dis.get_instructions(code):
+                for instruction in get_instructions(code):
                     if instruction.opname in (
                         "STORE_NAME",
                         "LOAD_NAME",
                         "LOAD_GLOBAL",
                         "STORE_FAST",
                         "LOAD_FAST",
+                        "LOAD_FAST_BORROW",
                         "LOAD_ATTR",
                         "STORE_ATTR",
                     ):
@@ -220,7 +211,7 @@ if sys.version_info >= (3, 11):
                         # STORE_NAME(_Test__subc11)
 
                         name = instruction.argval
-                        if name in ("__module__", "__qualname__", "__name__","__static_attributes__","__firstlineno__"):
+                        if name in ("__module__", "__qualname__", "__name__","__static_attributes__","__firstlineno__","__classdict__","__classdictcell__"):
                             continue
 
                         yield name
@@ -401,6 +392,14 @@ for __var in [1]:
         ) == {"Test","_","a", "self", "__thing"}
 
 
+        assert result(
+        "@__thing\n"
+        "class Test:\n"
+            "    pass"
+        )== {"Test","__thing"}
+    
+
+
 def test_pytest_rewrite():
     frame = inspect.currentframe()
 
